==> cdktf_cdktf_provider_azurerm-0.5.51-py3-none-any.whl: package/lib/bot-channel-sms.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface BotChannelSmsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#bot_name BotChannelSms#bot_name}
    */
    readonly botName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#location BotChannelSms#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#phone_number BotChannelSms#phone_number}
    */
    readonly phoneNumber: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#resource_group_name BotChannelSms#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#sms_channel_account_security_id BotChannelSms#sms_channel_account_security_id}
    */
    readonly smsChannelAccountSecurityId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#sms_channel_auth_token BotChannelSms#sms_channel_auth_token}
    */
    readonly smsChannelAuthToken: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#timeouts BotChannelSms#timeouts}
    */
    readonly timeouts?: BotChannelSmsTimeouts;
}
export interface BotChannelSmsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#create BotChannelSms#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#delete BotChannelSms#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#read BotChannelSms#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#update BotChannelSms#update}
    */
    readonly update?: string;
}
export declare function botChannelSmsTimeoutsToTerraform(struct?: BotChannelSmsTimeoutsOutputReference | BotChannelSmsTimeouts | cdktf.IResolvable): any;
export declare class BotChannelSmsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): BotChannelSmsTimeouts | undefined;
    set internalValue(value: BotChannelSmsTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms azurerm_bot_channel_sms}
*/
export declare class BotChannelSms extends cdktf.TerraformResource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms azurerm_bot_channel_sms} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options BotChannelSmsConfig
    */
    constructor(scope: Construct, id: string, config: BotChannelSmsConfig);
    private _botName?;
    get botName(): string;
    set botName(value: string);
    get botNameInput(): string | undefined;
    get id(): string;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _phoneNumber?;
    get phoneNumber(): string;
    set phoneNumber(value: string);
    get phoneNumberInput(): string | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    private _smsChannelAccountSecurityId?;
    get smsChannelAccountSecurityId(): string;
    set smsChannelAccountSecurityId(value: string);
    get smsChannelAccountSecurityIdInput(): string | undefined;
    private _smsChannelAuthToken?;
    get smsChannelAuthToken(): string;
    set smsChannelAuthToken(value: string);
    get smsChannelAuthTokenInput(): string | undefined;
    private _timeouts;
    get timeouts(): BotChannelSmsTimeoutsOutputReference;
    putTimeouts(value: BotChannelSmsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): BotChannelSmsTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.6.13-py3-none-any.whl: package/lib/bot-channel-sms.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface BotChannelSmsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#bot_name BotChannelSms#bot_name}
    */
    readonly botName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#location BotChannelSms#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#phone_number BotChannelSms#phone_number}
    */
    readonly phoneNumber: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#resource_group_name BotChannelSms#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#sms_channel_account_security_id BotChannelSms#sms_channel_account_security_id}
    */
    readonly smsChannelAccountSecurityId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#sms_channel_auth_token BotChannelSms#sms_channel_auth_token}
    */
    readonly smsChannelAuthToken: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#timeouts BotChannelSms#timeouts}
    */
    readonly timeouts?: BotChannelSmsTimeouts;
}
export interface BotChannelSmsTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#create BotChannelSms#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#delete BotChannelSms#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#read BotChannelSms#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms#update BotChannelSms#update}
    */
    readonly update?: string;
}
export declare function botChannelSmsTimeoutsToTerraform(struct?: BotChannelSmsTimeoutsOutputReference | BotChannelSmsTimeouts | cdktf.IResolvable): any;
export declare class BotChannelSmsTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): BotChannelSmsTimeouts | undefined;
    set internalValue(value: BotChannelSmsTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms azurerm_bot_channel_sms}
*/
export declare class BotChannelSms extends cdktf.TerraformResource {
    static readonly tfResourceType = "azurerm_bot_channel_sms";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/bot_channel_sms azurerm_bot_channel_sms} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options BotChannelSmsConfig
    */
    constructor(scope: Construct, id: string, config: BotChannelSmsConfig);
    private _botName?;
    get botName(): string;
    set botName(value: string);
    get botNameInput(): string | undefined;
    get id(): string;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _phoneNumber?;
    get phoneNumber(): string;
    set phoneNumber(value: string);
    get phoneNumberInput(): string | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    private _smsChannelAccountSecurityId?;
    get smsChannelAccountSecurityId(): string;
    set smsChannelAccountSecurityId(value: string);
    get smsChannelAccountSecurityIdInput(): string | undefined;
    private _smsChannelAuthToken?;
    get smsChannelAuthToken(): string;
    set smsChannelAuthToken(value: string);
    get smsChannelAuthTokenInput(): string | undefined;
    private _timeouts;
    get timeouts(): BotChannelSmsTimeoutsOutputReference;
    putTimeouts(value: BotChannelSmsTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): BotChannelSmsTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
